beamprofiler.iso.characterizing\_parameters.beam\_uniformity
============================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: beam_uniformity